Date: 2014-05-14 13:12:00

## Documentation

### 1 Scientific Publications

There are two papers associated with the theory and implementation of NanoCap. If NanoCap is used in your work, please cite the following:

1. Generalized method for constructing the atomic coordinates of nanotube caps
   M. Robinson, I. Suarez-Martinez, and N. A. Marks Phys. Rev. B 87, 155430

   Abstract:

   A practical numerical method for the rapid construction of nanotube caps is proposed. Founded upon the notion of lattice duality, the algorithm considers the face dual representation of a given nanotube which is used to solve an energy minimization problem analogous to The Thomson Problem. Not only does this produce caps for nanotubes of arbitrary chirality, but the caps generated will be physically sensible and in most cases the lowest energy structure. To demonstrate the applicability of the technique, caps of the (5,5) and the (10,0) nanotubes are investigated by means of density-functional tight binding (DFTB). The calculation of cap energies highlights the ability of the algorithm to produce lowest energy caps. Due to the preferential construction of spherical caps, the technique is particularly well suited for the construction of capped multiwall nanotubes (MWNTs). To validate this proposal and the overall robustness of the algorithm, a MWNT is constructed containing the chiralities (9,2)@(15,6)@(16,16). The algorithm presented paves the way for future computational investigations into the physics and chemistry of capped nanotubes.

   url: http://journals.aps.org/prb/abstract/10.1103/PhysRevB.87.155430

2. NanoCap: A Framework for Generating Capped Carbon Nanotubes and Fullerenes
   M. Robinson and N. A. Marks Com. Phys. Comm 2014

   Abstract:

   NanoCap provides both libraries and a standalone application for the construction of capped nanotubes of arbitrarily chirality and fullerenes of any radius. Structures are generated by constructing a set of optimal dual graph topologies which are subsequently optimised using a carbon interatomic potential. Combining this approach with a GUI featuring 3D rendering capabilities allows for the rapid inspection of physically sensible structures which can be used as input for molecular simulation.

   url: *tba*